@@ -31,7 +31,7 @@ class PairLocks():
 
     @staticmethod
     def lock_pair(pair: str, until: datetime, reason: str = None, *,
-                  now: datetime = None) -> PairLock:
+                  now: datetime = None, side: str = '*') -> PairLock:
         """
         Create PairLock from now to "until".
         Uses database by default, unless PairLocks.use_db is set to False,
@@ -40,12 +40,14 @@ class PairLocks():
         :param until: End time of the lock. Will be rounded up to the next candle.
         :param reason: Reason string that will be shown as reason for the lock
         :param now: Current timestamp. Used to determine lock start time.
+        :param side: Side to lock pair, can be 'long', 'short' or '*'
         """
         lock = PairLock(
             pair=pair,
             lock_time=now or datetime.now(timezone.utc),
             lock_end_time=timeframe_to_next_date(PairLocks.timeframe, until),
             reason=reason,
+            side=side,
             active=True
         )
         if PairLocks.use_db:
@@ -56,7 +58,8 @@ class PairLocks():
         return lock
 
     @staticmethod
-    def get_pair_locks(pair: Optional[str], now: Optional[datetime] = None) -> List[PairLock]:
+    def get_pair_locks(
+            pair: Optional[str], now: Optional[datetime] = None, side: str = '*') -> List[PairLock]:
         """
         Get all currently active locks for this pair
         :param pair: Pair to check for. Returns all current locks if pair is empty
@@ -67,26 +70,28 @@ class PairLocks():
             now = datetime.now(timezone.utc)
 
         if PairLocks.use_db:
-            return PairLock.query_pair_locks(pair, now).all()
+            return PairLock.query_pair_locks(pair, now, side).all()
         else:
             locks = [lock for lock in PairLocks.locks if (
                 lock.lock_end_time >= now
                 and lock.active is True
                 and (pair is None or lock.pair == pair)
+                and (lock.side == '*' or lock.side == side)
             )]
             return locks
 
     @staticmethod
-    def get_pair_longest_lock(pair: str, now: Optional[datetime] = None) -> Optional[PairLock]:
+    def get_pair_longest_lock(
+            pair: str, now: Optional[datetime] = None, side: str = '*') -> Optional[PairLock]:
         """
         Get the lock that expires the latest for the pair given.
         """
-        locks = PairLocks.get_pair_locks(pair, now)
-        locks = sorted(locks, key=lambda l: l.lock_end_time, reverse=True)
+        locks = PairLocks.get_pair_locks(pair, now, side=side)
+        locks = sorted(locks, key=lambda lock: lock.lock_end_time, reverse=True)
         return locks[0] if locks else None
 
     @staticmethod
-    def unlock_pair(pair: str, now: Optional[datetime] = None) -> None:
+    def unlock_pair(pair: str, now: Optional[datetime] = None, side: str = '*') -> None:
         """
         Release all locks for this pair.
         :param pair: Pair to unlock
@@ -97,7 +102,7 @@ class PairLocks():
             now = datetime.now(timezone.utc)
 
         logger.info(f"Releasing all locks for {pair}.")
-        locks = PairLocks.get_pair_locks(pair, now)
+        locks = PairLocks.get_pair_locks(pair, now, side=side)
         for lock in locks:
             lock.active = False
         if PairLocks.use_db:
@@ -134,7 +139,7 @@ class PairLocks():
                     lock.active = False
 
     @staticmethod
-    def is_global_lock(now: Optional[datetime] = None) -> bool:
+    def is_global_lock(now: Optional[datetime] = None, side: str = '*') -> bool:
         """
         :param now: Datetime object (generated via datetime.now(timezone.utc)).
             defaults to datetime.now(timezone.utc)
@@ -142,10 +147,10 @@ class PairLocks():
         if not now:
             now = datetime.now(timezone.utc)
 
-        return len(PairLocks.get_pair_locks('*', now)) > 0
+        return len(PairLocks.get_pair_locks('*', now, side)) > 0
 
     @staticmethod
-    def is_pair_locked(pair: str, now: Optional[datetime] = None) -> bool:
+    def is_pair_locked(pair: str, now: Optional[datetime] = None, side: str = '*') -> bool:
         """
         :param pair: Pair to check for
         :param now: Datetime object (generated via datetime.now(timezone.utc)).
@@ -154,7 +159,10 @@ class PairLocks():
         if not now:
             now = datetime.now(timezone.utc)
 
-        return len(PairLocks.get_pair_locks(pair, now)) > 0 or PairLocks.is_global_lock(now)
+        return (
+            len(PairLocks.get_pair_locks(pair, now, side)) > 0
+            or PairLocks.is_global_lock(now, side)
+        )
 
     @staticmethod
     def get_all_locks() -> List[PairLock]:
