@@ -1,10 +1,11 @@
 import logging
 from pathlib import Path
-from typing import Any, Dict, List, Optional
+from typing import Dict, List, Optional
 
 import pandas as pd
 
 from freqtrade.configuration import TimeRange
+from freqtrade.constants import Config
 from freqtrade.data.btanalysis import (analyze_trade_parallelism, extract_trades_of_period,
                                        load_trades)
 from freqtrade.data.converter import trim_dataframe
@@ -255,18 +256,18 @@ def plot_trades(fig, trades: pd.DataFrame) -> make_subplots:
     """
     # Trades can be empty
     if trades is not None and len(trades) > 0:
-        # Create description for sell summarizing the trade
+        # Create description for exit summarizing the trade
         trades['desc'] = trades.apply(
             lambda row: f"{row['profit_ratio']:.2%}, " +
             (f"{row['enter_tag']}, " if row['enter_tag'] is not None else "") +
             f"{row['exit_reason']}, " +
             f"{row['trade_duration']} min",
             axis=1)
-        trade_buys = go.Scatter(
+        trade_entries = go.Scatter(
             x=trades["open_date"],
             y=trades["open_rate"],
             mode='markers',
-            name='Trade buy',
+            name='Trade entry',
             text=trades["desc"],
             marker=dict(
                 symbol='circle-open',
@@ -277,12 +278,12 @@ def plot_trades(fig, trades: pd.DataFrame) -> make_subplots:
             )
         )
 
-        trade_sells = go.Scatter(
+        trade_exits = go.Scatter(
             x=trades.loc[trades['profit_ratio'] > 0, "close_date"],
             y=trades.loc[trades['profit_ratio'] > 0, "close_rate"],
             text=trades.loc[trades['profit_ratio'] > 0, "desc"],
             mode='markers',
-            name='Sell - Profit',
+            name='Exit - Profit',
             marker=dict(
                 symbol='square-open',
                 size=11,
@@ -290,12 +291,12 @@ def plot_trades(fig, trades: pd.DataFrame) -> make_subplots:
                 color='green'
             )
         )
-        trade_sells_loss = go.Scatter(
+        trade_exits_loss = go.Scatter(
             x=trades.loc[trades['profit_ratio'] <= 0, "close_date"],
             y=trades.loc[trades['profit_ratio'] <= 0, "close_rate"],
             text=trades.loc[trades['profit_ratio'] <= 0, "desc"],
             mode='markers',
-            name='Sell - Loss',
+            name='Exit - Loss',
             marker=dict(
                 symbol='square-open',
                 size=11,
@@ -303,9 +304,9 @@ def plot_trades(fig, trades: pd.DataFrame) -> make_subplots:
                 color='red'
             )
         )
-        fig.add_trace(trade_buys, 1, 1)
-        fig.add_trace(trade_sells, 1, 1)
-        fig.add_trace(trade_sells_loss, 1, 1)
+        fig.add_trace(trade_entries, 1, 1)
+        fig.add_trace(trade_exits, 1, 1)
+        fig.add_trace(trade_exits_loss, 1, 1)
     else:
         logger.warning("No trades found.")
     return fig
@@ -444,7 +445,7 @@ def generate_candlestick_graph(pair: str, data: pd.DataFrame, trades: pd.DataFra
     Generate the graph from the data generated by Backtesting or from DB
     Volume will always be ploted in row2, so Row 1 and 3 are to our disposal for custom indicators
     :param pair: Pair to Display on the graph
-    :param data: OHLCV DataFrame containing indicators and buy/sell signals
+    :param data: OHLCV DataFrame containing indicators and entry/exit signals
     :param trades: All trades created
     :param indicators1: List containing Main plot indicators
     :param indicators2: List containing Sub plot indicators
@@ -618,7 +619,7 @@ def store_plot_file(fig, filename: str, directory: Path, auto_open: bool = False
     logger.info(f"Stored plot as {_filename}")
 
 
-def load_and_plot_trades(config: Dict[str, Any]):
+def load_and_plot_trades(config: Config):
     """
     From configuration provided
     - Initializes plot-script
@@ -666,7 +667,7 @@ def load_and_plot_trades(config: Dict[str, Any]):
     logger.info('End of plotting process. %s plots generated', pair_counter)
 
 
-def plot_profit(config: Dict[str, Any]) -> None:
+def plot_profit(config: Config) -> None:
     """
     Plots the total profit for all pairs.
     Note, the profit calculation isn't realistic.
