@@ -4,6 +4,7 @@ This module loads custom exchanges
 import logging
 
 import freqtrade.exchange as exchanges
+from freqtrade.constants import Config
 from freqtrade.exchange import MAP_EXCHANGE_CHILDCLASS, Exchange
 from freqtrade.resolvers import IResolver
 
@@ -18,7 +19,8 @@ class ExchangeResolver(IResolver):
     object_type = Exchange
 
     @staticmethod
-    def load_exchange(exchange_name: str, config: dict, validate: bool = True) -> Exchange:
+    def load_exchange(exchange_name: str, config: Config, validate: bool = True,
+                      load_leverage_tiers: bool = False) -> Exchange:
         """
         Load the custom class from config parameter
         :param exchange_name: name of the Exchange to load
@@ -29,9 +31,13 @@ class ExchangeResolver(IResolver):
         exchange_name = exchange_name.title()
         exchange = None
         try:
-            exchange = ExchangeResolver._load_exchange(exchange_name,
-                                                       kwargs={'config': config,
-                                                               'validate': validate})
+            exchange = ExchangeResolver._load_exchange(
+                exchange_name,
+                kwargs={
+                    'config': config,
+                    'validate': validate,
+                    'load_leverage_tiers': load_leverage_tiers}
+            )
         except ImportError:
             logger.info(
                 f"No {exchange_name} specific subclass found. Using the generic class instead.")
