@@ -41,8 +41,8 @@ def get_exchange(config=Depends(get_config)):
     return ApiServer._exchange
 
 
-def get_channel_manager():
-    return ApiServer._ws_channel_manager
+def get_message_stream():
+    return ApiServer._message_stream
 
 
 def is_webserver_mode(config=Depends(get_config)):
