@@ -1,12 +1,12 @@
 from datetime import datetime, timedelta, timezone
+from pathlib import Path
 from unittest.mock import MagicMock, PropertyMock
 
 import pytest
 
-from freqtrade.enums import MarginMode, TradingMode
-from freqtrade.enums.candletype import CandleType
+from freqtrade.enums import CandleType, MarginMode, TradingMode
 from freqtrade.exchange.exchange import timeframe_to_minutes
-from tests.conftest import get_patched_exchange
+from tests.conftest import get_mock_coro, get_patched_exchange, log_has
 from tests.exchange.test_exchange import ccxt_exceptionhandlers
 
 
@@ -267,13 +267,16 @@ def test_additional_exchange_init_okx(default_conf, mocker):
                            "additional_exchange_init", "fetch_accounts")
 
 
-def test_load_leverage_tiers_okx(default_conf, mocker, markets):
+def test_load_leverage_tiers_okx(default_conf, mocker, markets, tmpdir, caplog, time_machine):
+
+    default_conf['datadir'] = Path(tmpdir)
+    # fd_mock = mocker.patch('freqtrade.exchange.exchange.file_dump_json')
     api_mock = MagicMock()
     type(api_mock).has = PropertyMock(return_value={
         'fetchLeverageTiers': False,
         'fetchMarketLeverageTiers': True,
     })
-    api_mock.fetch_market_leverage_tiers = MagicMock(side_effect=[
+    api_mock.fetch_market_leverage_tiers = get_mock_coro(side_effect=[
         [
             {
                 'tier': 1,
@@ -410,48 +413,66 @@ def test_load_leverage_tiers_okx(default_conf, mocker, markets):
     assert exchange._leverage_tiers == {
         'ADA/USDT:USDT': [
             {
-                'min': 0,
-                'max': 500,
-                'mmr': 0.02,
-                'lev': 75,
+                'minNotional': 0,
+                'maxNotional': 500,
+                'maintenanceMarginRate': 0.02,
+                'maxLeverage': 75,
                 'maintAmt': None
             },
             {
-                'min': 501,
-                'max': 1000,
-                'mmr': 0.025,
-                'lev': 50,
+                'minNotional': 501,
+                'maxNotional': 1000,
+                'maintenanceMarginRate': 0.025,
+                'maxLeverage': 50,
                 'maintAmt': None
             },
             {
-                'min': 1001,
-                'max': 2000,
-                'mmr': 0.03,
-                'lev': 20,
+                'minNotional': 1001,
+                'maxNotional': 2000,
+                'maintenanceMarginRate': 0.03,
+                'maxLeverage': 20,
                 'maintAmt': None
             },
         ],
         'ETH/USDT:USDT': [
             {
-                'min': 0,
-                'max': 2000,
-                'mmr': 0.01,
-                'lev': 75,
+                'minNotional': 0,
+                'maxNotional': 2000,
+                'maintenanceMarginRate': 0.01,
+                'maxLeverage': 75,
                 'maintAmt': None
             },
             {
-                'min': 2001,
-                'max': 4000,
-                'mmr': 0.015,
-                'lev': 50,
+                'minNotional': 2001,
+                'maxNotional': 4000,
+                'maintenanceMarginRate': 0.015,
+                'maxLeverage': 50,
                 'maintAmt': None
             },
             {
-                'min': 4001,
-                'max': 8000,
-                'mmr': 0.02,
-                'lev': 20,
+                'minNotional': 4001,
+                'maxNotional': 8000,
+                'maintenanceMarginRate': 0.02,
+                'maxLeverage': 20,
                 'maintAmt': None
             },
         ],
     }
+    filename = (default_conf['datadir'] /
+                f"futures/leverage_tiers_{default_conf['stake_currency']}.json")
+    assert filename.is_file()
+
+    logmsg = 'Cached leverage tiers are outdated. Will update.'
+    assert not log_has(logmsg, caplog)
+
+    api_mock.fetch_market_leverage_tiers.reset_mock()
+
+    exchange.load_leverage_tiers()
+    assert not log_has(logmsg, caplog)
+
+    api_mock.fetch_market_leverage_tiers.call_count == 0
+    # 2 day passes ...
+    time_machine.move_to(datetime.now() + timedelta(weeks=5))
+    exchange.load_leverage_tiers()
+
+    assert log_has(logmsg, caplog)
