@@ -6,6 +6,7 @@ import pytest
 from freqtrade import constants
 from freqtrade.enums import ExitType
 from freqtrade.persistence import PairLocks, Trade
+from freqtrade.persistence.trade_model import Order
 from freqtrade.plugins.protectionmanager import ProtectionManager
 from tests.conftest import get_patched_freqtradebot, log_has_re
 
@@ -30,12 +31,46 @@ def generate_mock_trade(pair: str, fee: float, is_open: bool,
         amount=0.01 / open_rate,
         exchange='binance',
         is_short=is_short,
+        leverage=1,
     )
+
+    trade.orders.append(Order(
+        ft_order_side=trade.entry_side,
+        order_id=f'{pair}-{trade.entry_side}-{trade.open_date}',
+        ft_is_open=False,
+        ft_pair=pair,
+        amount=trade.amount,
+        filled=trade.amount,
+        remaining=0,
+        price=open_rate,
+        average=open_rate,
+        status="closed",
+        order_type="market",
+        side=trade.entry_side,
+    ))
+    if not is_open:
+        trade.orders.append(Order(
+            ft_order_side=trade.exit_side,
+            order_id=f'{pair}-{trade.exit_side}-{trade.close_date}',
+            ft_is_open=False,
+            ft_pair=pair,
+            amount=trade.amount,
+            filled=trade.amount,
+            remaining=0,
+            price=open_rate * (2 - profit_rate if is_short else profit_rate),
+            average=open_rate * (2 - profit_rate if is_short else profit_rate),
+            status="closed",
+            order_type="market",
+            side=trade.exit_side,
+            ))
+
     trade.recalc_open_trade_value()
     if not is_open:
         trade.close(open_rate * (2 - profit_rate if is_short else profit_rate))
         trade.exit_reason = exit_reason
 
+    Trade.query.session.add(trade)
+    Trade.commit()
     return trade
 
 
@@ -94,33 +129,33 @@ def test_stoploss_guard(mocker, default_conf, fee, caplog, is_short):
     assert not log_has_re(message, caplog)
     caplog.clear()
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=200, min_ago_close=30, is_short=is_short,
-    ))
+    )
 
     assert not freqtrade.protections.global_stop()
     assert not log_has_re(message, caplog)
     caplog.clear()
     # This trade does not count, as it's closed too long ago
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'BCH/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=250, min_ago_close=100, is_short=is_short,
-    ))
+    )
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'ETH/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=240, min_ago_close=30, is_short=is_short,
-    ))
+    )
     # 3 Trades closed - but the 2nd has been closed too long ago.
     assert not freqtrade.protections.global_stop()
     assert not log_has_re(message, caplog)
     caplog.clear()
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'LTC/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=180, min_ago_close=30, is_short=is_short,
-    ))
+    )
 
     assert freqtrade.protections.global_stop()
     assert log_has_re(message, caplog)
@@ -155,25 +190,25 @@ def test_stoploss_guard_perpair(mocker, default_conf, fee, caplog, only_per_pair
     assert not log_has_re(message, caplog)
     caplog.clear()
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         pair, fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=200, min_ago_close=30, profit_rate=0.9, is_short=is_short
-    ))
+    )
 
     assert not freqtrade.protections.stop_per_pair(pair)
     assert not freqtrade.protections.global_stop()
     assert not log_has_re(message, caplog)
     caplog.clear()
     # This trade does not count, as it's closed too long ago
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         pair, fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=250, min_ago_close=100, profit_rate=0.9, is_short=is_short
-    ))
+    )
     # Trade does not count for per pair stop as it's the wrong pair.
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'ETH/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=240, min_ago_close=30, profit_rate=0.9, is_short=is_short
-    ))
+    )
     # 3 Trades closed - but the 2nd has been closed too long ago.
     assert not freqtrade.protections.stop_per_pair(pair)
     assert freqtrade.protections.global_stop() != only_per_pair
@@ -185,10 +220,10 @@ def test_stoploss_guard_perpair(mocker, default_conf, fee, caplog, only_per_pair
     caplog.clear()
 
     # Trade does not count potentially, as it's in the wrong direction
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         pair, fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=150, min_ago_close=25, profit_rate=0.9, is_short=not is_short
-    ))
+    )
     freqtrade.protections.stop_per_pair(pair)
     assert freqtrade.protections.global_stop() != only_per_pair
     assert PairLocks.is_pair_locked(pair, side=check_side) != (only_per_side and only_per_pair)
@@ -200,10 +235,10 @@ def test_stoploss_guard_perpair(mocker, default_conf, fee, caplog, only_per_pair
     caplog.clear()
 
     # 2nd Trade that counts with correct pair
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         pair, fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=180, min_ago_close=30, profit_rate=0.9, is_short=is_short
-    ))
+    )
 
     freqtrade.protections.stop_per_pair(pair)
     assert freqtrade.protections.global_stop() != only_per_pair
@@ -228,20 +263,20 @@ def test_CooldownPeriod(mocker, default_conf, fee, caplog):
     assert not log_has_re(message, caplog)
     caplog.clear()
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=200, min_ago_close=30,
-    ))
+    )
 
     assert not freqtrade.protections.global_stop()
     assert freqtrade.protections.stop_per_pair('XRP/BTC')
     assert PairLocks.is_pair_locked('XRP/BTC')
     assert not PairLocks.is_global_lock()
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'ETH/BTC', fee.return_value, False, exit_reason=ExitType.ROI.value,
         min_ago_open=205, min_ago_close=35,
-    ))
+    )
 
     assert not freqtrade.protections.global_stop()
     assert not PairLocks.is_pair_locked('ETH/BTC')
@@ -269,22 +304,24 @@ def test_LowProfitPairs(mocker, default_conf, fee, caplog, only_per_side):
     assert not log_has_re(message, caplog)
     caplog.clear()
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=800, min_ago_close=450, profit_rate=0.9,
-    ))
+    )
 
+    Trade.commit()
     # Not locked with 1 trade
     assert not freqtrade.protections.global_stop()
     assert not freqtrade.protections.stop_per_pair('XRP/BTC')
     assert not PairLocks.is_pair_locked('XRP/BTC')
     assert not PairLocks.is_global_lock()
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=200, min_ago_close=120, profit_rate=0.9,
-    ))
+    )
 
+    Trade.commit()
     # Not locked with 1 trade (first trade is outside of lookback_period)
     assert not freqtrade.protections.global_stop()
     assert not freqtrade.protections.stop_per_pair('XRP/BTC')
@@ -292,18 +329,20 @@ def test_LowProfitPairs(mocker, default_conf, fee, caplog, only_per_side):
     assert not PairLocks.is_global_lock()
 
     # Add positive trade
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.ROI.value,
         min_ago_open=20, min_ago_close=10, profit_rate=1.15, is_short=True
-    ))
+    )
+    Trade.commit()
     assert freqtrade.protections.stop_per_pair('XRP/BTC') != only_per_side
     assert not PairLocks.is_pair_locked('XRP/BTC', side='*')
     assert PairLocks.is_pair_locked('XRP/BTC', side='long') == only_per_side
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
-        min_ago_open=110, min_ago_close=20, profit_rate=0.8,
-    ))
+        min_ago_open=110, min_ago_close=21, profit_rate=0.8,
+    )
+    Trade.commit()
 
     # Locks due to 2nd trade
     assert freqtrade.protections.global_stop() != only_per_side
@@ -311,6 +350,7 @@ def test_LowProfitPairs(mocker, default_conf, fee, caplog, only_per_side):
     assert PairLocks.is_pair_locked('XRP/BTC', side='long')
     assert PairLocks.is_pair_locked('XRP/BTC', side='*') != only_per_side
     assert not PairLocks.is_global_lock()
+    Trade.commit()
 
 
 @pytest.mark.usefixtures("init_persistence")
@@ -329,36 +369,38 @@ def test_MaxDrawdown(mocker, default_conf, fee, caplog):
     assert not freqtrade.protections.stop_per_pair('XRP/BTC')
     caplog.clear()
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=1000, min_ago_close=900, profit_rate=1.1,
-    ))
-    Trade.query.session.add(generate_mock_trade(
+    )
+    generate_mock_trade(
         'ETH/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=1000, min_ago_close=900, profit_rate=1.1,
-    ))
-    Trade.query.session.add(generate_mock_trade(
+    )
+    generate_mock_trade(
         'NEO/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=1000, min_ago_close=900, profit_rate=1.1,
-    ))
+    )
+    Trade.commit()
     # No losing trade yet ... so max_drawdown will raise exception
     assert not freqtrade.protections.global_stop()
     assert not freqtrade.protections.stop_per_pair('XRP/BTC')
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=500, min_ago_close=400, profit_rate=0.9,
-    ))
+    )
     # Not locked with one trade
     assert not freqtrade.protections.global_stop()
     assert not freqtrade.protections.stop_per_pair('XRP/BTC')
     assert not PairLocks.is_pair_locked('XRP/BTC')
     assert not PairLocks.is_global_lock()
 
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.STOP_LOSS.value,
         min_ago_open=1200, min_ago_close=1100, profit_rate=0.5,
-    ))
+    )
+    Trade.commit()
 
     # Not locked with 1 trade (2nd trade is outside of lookback_period)
     assert not freqtrade.protections.global_stop()
@@ -368,20 +410,22 @@ def test_MaxDrawdown(mocker, default_conf, fee, caplog):
     assert not log_has_re(message, caplog)
 
     # Winning trade ... (should not lock, does not change drawdown!)
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.ROI.value,
         min_ago_open=320, min_ago_close=410, profit_rate=1.5,
-    ))
+    )
+    Trade.commit()
     assert not freqtrade.protections.global_stop()
     assert not PairLocks.is_global_lock()
 
     caplog.clear()
 
     # Add additional negative trade, causing a loss of > 15%
-    Trade.query.session.add(generate_mock_trade(
+    generate_mock_trade(
         'XRP/BTC', fee.return_value, False, exit_reason=ExitType.ROI.value,
         min_ago_open=20, min_ago_close=10, profit_rate=0.8,
-    ))
+    )
+    Trade.commit()
     assert not freqtrade.protections.stop_per_pair('XRP/BTC')
     # local lock not supported
     assert not PairLocks.is_pair_locked('XRP/BTC')
@@ -393,7 +437,7 @@ def test_MaxDrawdown(mocker, default_conf, fee, caplog):
 @pytest.mark.parametrize("protectionconf,desc_expected,exception_expected", [
     ({"method": "StoplossGuard", "lookback_period": 60, "trade_limit": 2, "stop_duration": 60},
      "[{'StoplossGuard': 'StoplossGuard - Frequent Stoploss Guard, "
-     "2 stoplosses within 60 minutes.'}]",
+     "2 stoplosses with profit < 0.00% within 60 minutes.'}]",
      None
      ),
     ({"method": "CooldownPeriod", "stop_duration": 60},
@@ -411,9 +455,9 @@ def test_MaxDrawdown(mocker, default_conf, fee, caplog):
      None
      ),
     ({"method": "StoplossGuard", "lookback_period_candles": 12, "trade_limit": 2,
-      "stop_duration": 60},
+      "required_profit": -0.05, "stop_duration": 60},
      "[{'StoplossGuard': 'StoplossGuard - Frequent Stoploss Guard, "
-     "2 stoplosses within 12 candles.'}]",
+     "2 stoplosses with profit < -5.00% within 12 candles.'}]",
      None
      ),
     ({"method": "CooldownPeriod", "stop_duration_candles": 5},
